PBI Tools
=========

PBI Tools is an object-orientated Python library that makes working with Power BI files easier.

Alpha Warning
-------------

This library is currently in **alpha**.
Use with caution and feel free to raise any issues on the [GitHub page](https://github.com/thomas-daughters/pbi-tools/issues).

Documentation
-------------

Full documentation can be found on [Read the Docs](https://pbi-tools.readthedocs.io).

License
-------

It is made available under the [MIT license](https://raw.github.com/thomas-daughters/pbi-tools/main/LICENSE).